% Tested in Matlab R2021a
% Adapted from: Kaleefathullah, A. A., Merat, N., Lee, Y. M., Eisma, Y. B., Madigan, R., Garcia, J., & De Winter, J. C. F. (in press). External Human-Machine Interfaces can be misleading: An examination of trust development and misuse in a CAVE-based pedestrian simulation environment. Human Factors. https://doi.org/10.1177/0018720820970751
% Joost de Winter, May 2022
%%
clear all;close all;clc %#ok<CLALL>
fullsample=0; % set to 1 if wanting to evaluate the full sample (N = 60); set to 0 if wanting to exclude invalid participants
load all_data

% Speed340 - Speed some time into the trial (used to extract whether the trial was a yielding 33 m trial, yielding 43 m trial, or a no-yielding trial)
% eHMIon - Sum of the eHMI intensity values (used for defining whether the eHMI was on in this trial)            

% Block 1: Trial 1-12
% Block 2: Trial 13-24
% Block 3: Trial 25-36
% Block 4: Trial 38-49
% Trials 37 & 50 are failure trials. In the failure trials, the eHMI is on but the car does not stop

% Per block:
% 4 trials No Braking & eHMI off
% 4 trials Braking at 43 m (1 of which with eHMI off)
% 4 trials Braking at 33 m (1 of which with eHMI off)

% Participant 1, 3, 5, ... belong to the +1 Group
% Participant 2, 4, 6, ... beling to the -1 Group

% Lane boundaries from 2.826 m till -1.363 m
% This corresponds to 2.050 m 6.239 m after correcting the z position so that z = 0 m corresponds to the starting position of the pedestrian
%% Extract trial type
for pp=1:60 % loop over participants
    BrakingDistanceAll(pp,Speed340(pp,:)> 27 &Speed340(pp,:) < 29.5)=33; % store in 60 x 50 matrix BrakingDistanceAll that this is a yielding 33 m trial
    BrakingDistanceAll(pp,Speed340(pp,:)> 24 &Speed340(pp,:) < 26)=43;   % store in 60 x 50 matrix BrakingDistanceAll that this is a yielding 43 m trial
    BrakingDistanceAll(pp,Speed340(pp,:)> 29.6)=999;                     % store in 60 x 50 matrix BrakingDistanceAll that this is a non-yielding trial (no braking)
end
eHMIOn=eHMIOn>0; % make the eHMI intensity sum binary. It the sum exceeds 0, this must have been an eHMI On trial. There are 26 eHMI On trials per participant
%% Sort the measures (scores) in matrices, making a distinction between vehicle behavior
[PedestrianZVehBehavior,VehicleXVehBehavior]=deal(NaN(60,7,26,2172)); % (60 participants x 7 vehicle behaviors x 26 trials x 2172 data points)
for Blocks=1:4 % loop over 4 blcoks
    for pp=1:60 % loop over 60 participants
        if Blocks==1 % only do this once
            IndexAll=NaN(7,26); % Create for this participant a 7 x 26 matrix containing the indexes of trials (1 to 50) per trial type
            IndexAll(1,1:12)=find(BrakingDistanceAll(pp,:)==33 & eHMIOn(pp,:)==1);  % 33 m, eHMI on (12 trials)
            IndexAll(2,1:4) =find(BrakingDistanceAll(pp,:)==33 & eHMIOn(pp,:)==0);  % 33 m, eHMI off (4 trials)
            IndexAll(3,1:12)=find(BrakingDistanceAll(pp,:)==43 & eHMIOn(pp,:)==1);  % 43 m, eHMI on (12 trials)
            IndexAll(4,1:4) =find(BrakingDistanceAll(pp,:)==43 & eHMIOn(pp,:)==0);  % 43 m, eHMI off (4 trials)
            IndexAll(5,1:16)=find(BrakingDistanceAll(pp,:)==999 & eHMIOn(pp,:)==0); % non-yielding, eHMI off (16 trials)
            IndexAll(6,1:26)=find(eHMIOn(pp,:)==1);                                 % eHMI on (26 trials; i.e., 6 per block x 4 blocks = 24 + 2 failure trials = 26)
            IndexAll(7,1:18)=find(BrakingDistanceAll(pp,:)==999);                   % non-yielding (18 trials)
            for VehicleBehavior=1:7 % loop over the 7 types of vehicle behavior as defined above
                temp=squeeze(PedestrianZall(pp,IndexAll(VehicleBehavior,IndexAll(VehicleBehavior,:)>0),:)); % Pedestrian position of trials of a particular vehicle behavior x 2172 time stamps
                PedestrianZVehBehavior(pp,VehicleBehavior,1:size(temp,1),1:size(temp,2))=temp; % Store in matrix (60 participants x 7 vehicle behaviors x 26 trials x 2172 data points)
                temp=squeeze(VehicleXall(pp,IndexAll(VehicleBehavior,IndexAll(VehicleBehavior,:)>0),:)); % Vehicle position of trials of a particular vehicle behavior x 2172 time stamps
                VehicleXVehBehavior(pp,VehicleBehavior,1:size(temp,1),1:size(temp,2))=temp; % Store in matrix (60 participants x 7 vehicle behaviors x 26 trials x 2172 data points)
            end
        end
    end
end
%% Figure 1. Mean pedestrian position perpendicular to the road as a function of elapsed time in failure trial 1. A distinction is made between pedestrians who were on the road when the car passed, and pedestrians who were not on the road when the car passed.
PedPositionWhenCarPasses=deal(NaN(60,18));
for pp=1:60 % loop over 60 participants
    for trial=1:18 % loop over the 18 trials in which the vehicle was not yielding
        [~,carpasses]=min(abs(squeeze(VehicleXVehBehavior(pp,7,trial,:)))); % find the index of the minimum vehicle position in that trial, i.e.,the moment the car passed
        if ~isempty(carpasses)
            pedestrian_position_in_trial=squeeze(PedestrianZVehBehavior(pp,7,trial,:)); % pedestrian position in that trial
            PedPositionWhenCarPasses(pp,trial)=pedestrian_position_in_trial(carpasses); % store the pedestrian position when the non-yielding vehicle passes
        end
    end
end

invalidpp=find(sum(PedPositionWhenCarPasses'>2.050)>6);   % Participants who were on the road or had already crossed the road at the moment the non-yielding AV passed in more than 6 out of 18 non-yielding trials (i.e., 4 trials per block plus 2 failure trials) were excluded from all analyses.
validpp=find(~ismember(1:60,invalidpp));                  % Valid participants are participants who are not invalid particiapnts
odd=1:2:60;
validpp_odd=odd(~ismember(odd,invalidpp));                % Valid participants in the +1 Group
even=2:2:60;
validpp_even=even(~ismember(even,invalidpp));             % Valid participants in the -1 Group
if fullsample==1
    validpp_odd=odd;validpp_even=even;validpp=1:60; % uncomment for generating the Figures and Tables of the appendices
end

d1=squeeze(nanmean(PedestrianZVehBehavior(:,1,:,:),3)); % 33 m, eHMI on (12 trials)
time=0.01:0.01:length(d1)/100; % time vector (100 Hz)

PedPositionFT1=squeeze(nanmean(PedestrianZVehBehavior(:,7,13,:),3));

figure; hold on;box on;grid on
I = imread('Pavement.png');
h = image([0 6.5],[-.5 7.5],I);
uistack(h,'bottom')
patch([-1 17 17 -1],[2.050 2.050 6.239 6.239],[0 0 0],'FaceColor','k','edgecolor','none')
image('CData',imread('Road.png'),'XData',[0 6.5],'YData',[2.065 6.224])

plot([time(1) time(end)],[-9999 -9999],'color',[98 183 252]/255,'Linewidth',3) % plot a dummy line (used for creating the legend)
plot([time(1) time(end)],[-9999 -9999],'r-','Linewidth',3) % plot a dummy line (used for creating the legend)
plot([time(1) time(end)],[-9999 -9999],'g-','Linewidth',5) % plot a dummy line (used for creating the legend)
onindex=find(squeeze(eHMIintensityall(1,37,:))>0,1,'first');
plot(time(onindex),-.5,'mo','markerfacecolor','m','markersize',17) % plot magenta marker for the eHMI onset moment
plot(time(1:2:end),PedPositionFT1(intersect(validpp,find(PedPositionWhenCarPasses(:,13)> 2.050 & PedPositionWhenCarPasses(:,13)< 6.239)),1:2:end),'r-','Linewidth',3) % on the road
plot(time(1:2:end),PedPositionFT1(intersect(validpp,find(PedPositionWhenCarPasses(:,13)<=2.050 | PedPositionWhenCarPasses(:,13)>=6.239)),1:2:end),'-','color',[98 183 252]/255,'Linewidth',3) % not on the road
plot([time(598) time(598)],[3.179 5.079],'g','Linewidth',5)

legend('','Not on the road when the AV passed','On the road when the AV passed','AV passes','eHMI onset','location','northwest','autoupdate','off');
h=findobj('FontName','Helvetica'); set(h,'FontSize',24,'Fontname','Arial')
set(gca,'xlim',[0 6.5],'ylim',[-.5 7.5],'TickDir','out','LooseInset',[0.01 0.01 0.01 0.01],'xtick',0:1:15)
xlabel('Elapsed time (s)')
ylabel('Pedestrian position perpendicular to the road (m)')
set(gcf,'WindowState','maximized');print(gcf,'Figure1.png','-dpng','-r300');